@@ -11,7 +11,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 
 
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 
 sub new {
   my $this = shift;
@@ -191,9 +191,11 @@ sub delrange {
 
 sub range {
   my $self = shift;
+  my $excludeLarge = shift;
   if (wantarray) {
     my @range = keys(%{$self->{_rangehash}});
-    if(exists($self->{_largeRangehash})) {
+    if(! $excludeLarge
+       && exists($self->{_largeRangehash})) {
         foreach my $rangeID (keys(%{$self->{_largeRangehash}})) {
           my $range = $self->{_largeRangehash}->{$rangeID};
             if ( @$range[0] > LONG_MAX
@@ -202,7 +204,7 @@ sub range {
                 carp "Range to large to return" if (warnings::enabled());
                 return 0;
             }
-            
+
             @range = (@range, @$range[0]..@$range[1]);
         }
     }
@@ -216,7 +218,7 @@ sub range {
     foreach my $current (@range) {
       if ($current == ($previous + 1)) {
         $format =~ s/\.\.$previous$//;
-        $format .= "..$current"; 
+        $format .= "..$current";
       }
       else {
         $format .= ",$current";
@@ -236,10 +238,46 @@ sub size {
       my $range = $self->{_largeRangehash}->{$rangeID};
       $size += (@$range[1] - @$range[0]) + 1;
     }
-  }  
+  }
   return $size;
 }
 
+sub rangeList {
+  my $self = shift;
+  my @return;
+  # Get the range as an array (excluding large ones)
+  my @range = $self->range(1);
+
+  # If we have any ranges
+  if (@range) {
+
+    # Get the first element in the array range
+    my $previous = shift(@range);
+    my @sub = ($previous);
+
+    # Process ranges stored as arrays
+    foreach my $current (@range) {
+        if ($current == ($previous + 1)) {
+            $sub[1] = $current;
+        } else {
+            push(@return,[@sub]);
+            @sub = ($current);
+        }
+        $previous = $current;
+    }
+    push(@return,[@sub]);
+  }
+
+  # Process ranges stored as large range hash entries
+  if($self->{_largeRangehash}) {
+      while(my @range = each(%{$self->{_largeRangehash}}) ) {
+          push(@return, [int($range[1][0]), int($range[1][1])]);
+      }
+  }
+
+  return @return;
+}
+
 1;
 __END__
 
@@ -280,16 +318,16 @@ this, much like Perl's own binary C<..> range operator in list context.
 
 =item new
 
-  $range = Number::Range->new("10..20","25..30");
+  $range = Number::Range->new("10..20","25..30","100");
 
-Creates the range object. It will accept any number of ranges as its 
+Creates the range object. It will accept any number of ranges as its
 input.
 
 =item addrange
 
   $range->addrange("22");
 
-This will also take any number of ranges as input and add them to the 
+This will also take any number of ranges as input and add them to the
 existing range.
 
 =item delrange
@@ -323,6 +361,21 @@ string.
 
 This will return the total number of entries in the range.
 
+
+=item rangeList
+
+  @rangeList = $range->rangeList;
+
+Returns the range as an array list where each element in the list is an array
+representing the start and stop points of a range. Single element ranges are
+returned as single element arrays with only on indice.
+
+[
+  [10,20],
+  [25,30],
+  [100]
+]
+
 =back
 
 =head2 EXPORT
@@ -340,7 +393,7 @@ Larry Shatzer, Jr., E<lt>larrysh@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-12 by Larry Shatzer, Jr.
+Copyright (C) 2004-14 by Larry Shatzer, Jr.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
